.. _module-docs:

SymPy Modules Reference
=======================

Because every feature of SymPy must have a test case, when you are not sure how
to use something, just look into the ``tests/`` directories, find that feature
and read the tests for it, that will tell you everything you need to know.

Most of the things are already documented though in this document, that is
automatically generated using SymPy's docstrings.

Click the  "modules" (:ref:`modindex`) link in the top right corner to easily
access any SymPy module, or use this contens:

.. toctree::
   :maxdepth: 2

   core.rst
   combinatorics/index.rst
   ntheory.rst
   crypto.rst
   concrete.rst
   evalf.rst
   numeric-computation.rst
   functions/index.rst
   galgebra/index.rst
   geometry.rst
   integrals/integrals.rst
   logic.rst
   matrices/index.rst
   Mpmath <mpmath/index.rst>
   polys/index.rst
   printing.rst
   plotting.rst
   assumptions/index.rst
   rewriting.rst
   series.rst
   sets.rst
   simplify/simplify.rst
   simplify/hyperexpand.rst
   statistics.rst
   stats.rst
   solvers/ode.rst
   solvers/pde.rst
   solvers/solvers.rst
   solvers/diophantine.rst
   solvers/inequalities.rst
   tensor/index.rst
   utilities/index.rst
   parsing.rst
   calculus/index.rst
   physics/index.rst
   categories.rst
   diffgeom.rst

Contributions to docs
---------------------

All contributions are welcome. If you'd like to improve something, look into
the sources if they contain the information you need (if not, please fix them),
otherwise the documentation generation needs to be improved (look in the
``doc/`` directory).
